@@ -2,7 +2,7 @@
 # __init__.py
 # Python bindings for libparted (built on top of the _ped Python module).
 #
-# Copyright (C) 2007, 2008, 2009 Red Hat, Inc.
+# Copyright (C) 2007, 2008, 2009  Red Hat, Inc.
 #
 # This copyrighted material is made available to anyone wishing to use,
 # modify, copy, or redistribute it subject to the terms and conditions of
@@ -45,6 +45,7 @@ from constraint import Constraint
 from device import Device
 from disk import Disk
 from disk import diskType
+from disk import diskFlag
 from filesystem import FileSystem
 from filesystem import fileSystemType
 from geometry import Geometry
@@ -79,11 +80,10 @@ from _ped import DEVICE_UBD
 from _ped import DEVICE_DASD
 from _ped import DEVICE_VIODASD
 from _ped import DEVICE_SX8
-try:
-    from _ped import DEVICE_DM
-except:
-    pass
+from _ped import DEVICE_DM
 from _ped import DEVICE_XVD
+from _ped import DEVICE_SDMMC
+from _ped import DEVICE_VIRTBLK
 
 from _ped import PARTITION_NORMAL
 from _ped import PARTITION_LOGICAL
@@ -103,10 +103,16 @@ from _ped import PARTITION_HPSERVICE
 from _ped import PARTITION_PALO
 from _ped import PARTITION_PREP
 from _ped import PARTITION_MSFT_RESERVED
+from _ped import PARTITION_APPLE_TV_RECOVERY
+from _ped import PARTITION_BIOS_GRUB
+
+from _ped import DISK_CYLINDER_ALIGNMENT
 
 from _ped import DISK_TYPE_EXTENDED
 from _ped import DISK_TYPE_PARTITION_NAME
 
+from decorators import localeC
+
 partitionTypesDict = {
     0x00: "Empty",
     0x01: "DOS 12-bit FAT",
@@ -185,9 +191,14 @@ partitionTypesDict = {
 #   mb    megabytes   1024^2 = 1048576
 #   gb    gigabytes   1024^3 = 1073741824
 #   tb    terabytes   1024^4 = 1099511627776
+#   pb    petabytes   1024^5 = 1125899906842624
+#   eb    exabytes    1024^6 = 1152921504606846976
+#   zb    zettabytes  1024^7 = 1180591620717411303424
+#   yb    yottabytes  1024^8 = 1208925819614629174706176
 # The resulting value for 1024 raised to the power is used as
 # the divisor for conversion functions.
-_exponent = {'b': 0, 'kb': 1, 'mb': 2, 'gb': 3, 'tb': 4}
+_exponent = {'b': 0, 'kb': 1, 'mb': 2, 'gb': 3, 'tb': 4,
+             'pb': 5, 'eb': 6, 'zb': 7, 'yb': 8}
 
 # Valid disk labels per architecture type.  The list of label
 # names map to keys in the parted.diskType hash table.
@@ -211,12 +222,14 @@ class WriteOnlyProperty(Exception):
     def __init__(self, property=''):
         self.message = "%s is a write-only property" % (property,)
 
+@localeC
 def getDevice(path):
     """Given the operating system level path to a device node, return
        a Device object for that disk.  Raises DeviceException if an invalid
        path is given."""
     return Device(path=path)
 
+@localeC
 def getAllDevices():
     """Return a list of Device objects for all devices in the system."""
     from _ped import device_probe_all
@@ -238,11 +251,13 @@ def getAllDevices():
         except IndexError:
             return lst
 
+@localeC
 def freeAllDevices():
     """Free all Device objects.  There is no reason to call this function."""
     from _ped import device_free_all
     return device_free_all()
 
+@localeC
 def probeForSpecificFileSystem(fstype, geometry):
     """Call the _ped.file_system_probe_specific() function given the
        filesystem type and geometry.  fstype must be a string
@@ -252,6 +267,7 @@ def probeForSpecificFileSystem(fstype, geometry):
     geom = file_system_probe_specific(fileSystemType[fstype], geometry.getPedGeometry())
     return geometry.Geometry(PedGeometry=geom)
 
+@localeC
 def probeFileSystem(geometry):
     """Return the name of the filesystem detected on the given
        Geometry.  Returns None is no filesystem found."""
@@ -259,6 +275,7 @@ def probeFileSystem(geometry):
     fstype = file_system_probe(geometry.getPedGeometry())
     return fstype.name
 
+@localeC
 def freshDisk(device, ty):
     """Return a Disk object for this Device and using this DiskType.
        The type should be a member of the parted.diskType hash,
@@ -276,6 +293,7 @@ def freshDisk(device, ty):
     peddisk = disk_new_fresh(device.getPedDevice(), ty)
     return Disk(PedDisk=peddisk)
 
+@localeC
 def version():
     """Return a dict containing the pyparted and libparted versions."""
     from _ped import libparted_version
